Struct stream_httparse::streaming_parser::ChunkParser[][src]

pub struct ChunkParser { /* fields omitted */ }
A single ChunkParser instance used to parse multiple Chunks one after the other

Implementations

Creates a new empty Instance of the ChunkParser that is ready to start parsing Request

Clears and resets the internal State to allow the parser to accept, receive and parse a new chunk without using up extra allocations,

Parses the given Block of data, returns the size it parsed as well as if it is done with parsing

Returns:

  • If it is done and the finish function should be called
  • The amount of data that is still left in the Buffer (at the end)

Finishes the Parsing and returns the finsihed Chunk