Enum stream_httparse::streaming_parser::ParseError [−][src]
pub enum ParseError {
MissingMethod,
MissingPath,
MissingProtocol,
MissingHeaders,
MissingStatusCode,
InvalidStatusCode,
}Expand description
Indicates all Errors related to parsing a Request/Response/Chunk
Variants
MissingMethod
Could not find a valid Method in the Request
MissingPath
Could not find a valid Path in the Request
MissingProtocol
Could not identify the Protocol of the Request/Response
MissingHeaders
Could not find any headers in the Request/Response
MissingStatusCode
Could not find a StatusCode in the Response
InvalidStatusCode
Returned StatusCode is not valid